@@ -1,15 +1,19 @@
 # -*- coding: utf-8 -*-
 
 
-__author__="Michael/Binkcn"
+__author__="Michael/Binkcn/l32606"
 __date__ ="$2011-09-04$"
 
+import dbus
+import dbus.glib
+import osso
+
 import sys
 import os
 from PyQt4.QtCore import *
 from PyQt4.QtGui import *
 import logging
-from datetime import datetime
+from datetime import *
 from UI import *
 from Controller import Controller
 #from Updater import *
@@ -20,6 +24,18 @@ from weibopy.error import WeibopError
 from PyQt4.QtMaemo5 import QMaemo5InformationBox
 from flickcharm import FlickCharm
 
+
+# Define some constants
+MCE_SIGNAL_NAME = 'sig_device_orientation_ind'
+MCE_SIGNAL_IFACE = 'com.nokia.mce.signal'
+MCE_SIGNAL_PATH = '/com/nokia/mce/signal'
+
+
+MCE_SERVICE = 'com.nokia.mce'
+MCE_REQUEST_PATH =  '/com/nokia/mce/request'
+MCE_REQUEST_IF = 'com.nokia.mce.request'
+MCE_DEVICE_ORIENTATION_GET = 'get_device_orientation'
+
 class MaoboApp(QApplication):
     def __init__(self, parent=None):
         self.logger = logging.getLogger('maebo')
@@ -45,11 +61,13 @@ class MaoboApp(QApplication):
         self.connect(self.sendersina, SIGNAL("finished(bool)"), self.send_finished)
         self.connect(self.updatersina, SIGNAL("show_notice(QString,int)"), self.show_notice)
         self.connect(self.sendersina, SIGNAL("show_notice(QString,int)"), self.show_notice)
-        
+        self.connect(self.updatersina, SIGNAL("cm_finished(bool)"), self.update_comments_finished)
+
         self.connect(self.updaterqq, SIGNAL("finished(bool)"), self.update_finished)
         self.connect(self.senderqq, SIGNAL("finished(bool)"), self.send_finished)
         self.connect(self.updaterqq, SIGNAL("show_notice(QString,int)"), self.show_notice)
         self.connect(self.senderqq, SIGNAL("show_notice(QString,int)"), self.show_notice)
+        self.connect(self.updaterqq, SIGNAL("cm_finished(bool)"), self.update_comments_finished)
         
         self.currentStatus=None
         self.timelineType=None
@@ -59,21 +77,84 @@ class MaoboApp(QApplication):
         
         self.currentAccount=None
 
+        self.commentid_seed = 0
         self.create_default_window()
         self.create_accounts_window()
-        self.create_menus_window()
+        #self.create_menus_window()
         self.create_timeline_window()
         self.create_status_window()
+        #self.newStatusWin=NewStatusWindow(self.menusWin, self.orientation)
         self.newStatusWin=None
         self.accountsManaForm=None
         self.newAccountForm=None
 
+        Utils.g_orietation=self.get_current_orientation()
+
+    # Get the system bus
+        sysbus=dbus.Bus.get_system()
+
+    # Connect the "handler" to the orientation changed signal of mce
+        sysbus.add_signal_receiver(self.OrientationHandler, signal_name=MCE_SIGNAL_NAME, dbus_interface=MCE_SIGNAL_IFACE, path=MCE_SIGNAL_PATH)
+
         if len(self.accounts)==0:
             self.defaultWin.show()
         else:
             self.accountsWin.show()
             
+    def get_current_orientation(self):
+        '''
+        f = open("/sys/class/i2c-adapter/i2c-3/3-001d/coord", 'r' )
+        x,y,z = [int(w) for w in f.readline().split()]
+        f.close()
         
+        if abs(x)<500: 
+            print "landscape"
+            return 0#LANDSCAPE
+        else:
+            print "portrait"
+            return 1#PORTRAIT
+       '''            
+        osso_c = osso.Context("Maebo","0.0.1",False) 
+        orientation=None
+
+        rpc = osso.Rpc(osso_c)
+        orientation =rpc.rpc_run(MCE_SERVICE, MCE_REQUEST_PATH, MCE_REQUEST_IF, MCE_DEVICE_ORIENTATION_GET,
+            wait_reply=True, use_system_bus=True)       
+            
+        if orientation == 'landscape': 
+            return 0
+        elif orientation == "landscape (inverted)": 
+            return 2
+        elif orientation == 'portrait':
+            return 1
+        elif orientation ==  "portrait (inverted)":
+            return 3
+       
+
+            
+# Define a callback that gets called for orientation changes
+    def OrientationHandler(self, orientation, stand, face, x, y, z):   
+        #print "OrientationHandler"
+        #print orientation
+        if orientation == 'landscape': 
+            Utils.g_orietation = 0
+            self.newStatusWin.switch(0)
+            self.timelineWin.switch(0)
+            #print "landscape"
+        elif orientation == "landscape (inverted)": 
+            Utils.g_orietation = 2
+            self.newStatusWin.switch(2)
+            self.timelineWin.switch(2)
+            #print "landscape"
+        elif orientation == 'portrait':
+            Utils.g_orietation = 1
+            self.newStatusWin.switch(1)
+            self.timelineWin.switch(1)
+        elif orientation ==  "portrait (inverted)":
+            Utils.g_orietation = 3
+            self.newStatusWin.switch(3)
+            self.timelineWin.switch(3)
+            
     def create_default_window(self):
         self.defaultWin=DefaultWindow(None)
         accountsManaAction = self.create_action(unicode("账户管理"), self.show_accounts_mana_form)
@@ -128,35 +209,44 @@ class MaoboApp(QApplication):
             self.show_notice(we)
             
         self.logger.debug(self.currentAccount["username"]+" choosed.")
-        self.menusWin.show()
+        #self.menusWin.setWindowTitle(self.currentAccount["nickname"])
+        #self.menusWin.show()
+        self.timelineType=Utils.TIMELINE_TYPE_FRIENDS
+        self.timelineWin.currentMenuIdx = 0
+        model = self.timelineWin.menuListView.model()
+        self.timelineWin.menuListView.setCurrentIndex(model.index(0, 0))
+        self.show_timeline_window()
 
     def create_menus_window(self):
         self.menus=Utils.build_menus()
-        self.menusWin=MenusWindow(self.accountsWin,self.menus)
+        self.menusWin=MenusWindow(self.accountsWin,self.menus) #, self.currentAccount["nickname"])
 
-        self.connect(self.menusWin.menuListView,
-                     SIGNAL("clicked(const QModelIndex&)"),
-                     self.menu_clicked)
+        #self.connect(self.menusWin.menuListView,SIGNAL("clicked(const QModelIndex&)"),self.menu_clicked)
 
 
     def menu_clicked(self,index):
+        #print "menu_clicked"
         self.logger.debug("menu_clicked")
         row=index.row()
-        menu=self.menus[row]
+        menu=self.timelineWin.menus[row]
         self.logger.debug(menu["name"]+" choosed.")
         value=menu["value"]
         
         if value==Utils.NEW_A_STATUS:
+            model = self.timelineWin.menuListView.model()
+            self.timelineWin.menuListView.setCurrentIndex(model.index(self.timelineWin.currentMenuIdx, 0))
             self.show_new_status_window()
         else:
+            self.timelineWin.currentMenuIdx = index.row()
             self.timelineType=value
             self.show_timeline_window()
 
+
     def create_timeline_window(self):
-        self.timelineWin=TimelineWindow(self.menusWin)
-        self.connect(self.timelineWin.statusesListView,
-                     SIGNAL("clicked(const QModelIndex&)"),
-                     self.status_clicked)
+        self.timelineWin=TimelineWindow(self.accountsWin, orientation=Utils.g_orietation)
+        self.connect(self.timelineWin.statusesListView,SIGNAL("clicked(const QModelIndex&)"),self.status_clicked)
+        self.connect(self.timelineWin.menuListView,SIGNAL("clicked(const QModelIndex&)"),self.menu_clicked)
+        
         self.updateOpe=Utils.build_an_operation(Utils.STATUS_OPE_TYPE_UPDATE,
                                           "Click to update",
                                           Utils.get_last_update_time_by_timeline_type(self.currentAccount,self.timelineType))
@@ -167,11 +257,15 @@ class MaoboApp(QApplication):
         self.currentOpe=None
 
     def create_status_window(self):
-        self.statusWin=StatusWindow(self.timelineWin)
+        self.statusWin=StatusWindow(self.timelineWin)        
+        self.connect(self.statusWin.statusesListView, SIGNAL("clicked(const QModelIndex&)"), self.cm_List_clicked)
+        self.connect(self.statusWin.cmBtn, SIGNAL("clicked()"), self.cm_status_clicked)            
+
         self.connect(self.statusWin.rtBtn, SIGNAL("clicked()"), self.rt_a_status)
         self.connect(self.statusWin.cmtBtn, SIGNAL("clicked()"), self.comment_a_status)
         self.connect(self.statusWin.dmBtn, SIGNAL("clicked()"), self.dm_a_status)
         self.connect(self.statusWin.favBtn, SIGNAL("clicked()"), self.fav_a_status)
+        self.connect(self.statusWin.ReplyBtn, SIGNAL("clicked()"), self.Reply_a_status)
         self.charm.activateOn(self.statusWin.statusContentView)
 
     def show_timeline_window(self):
@@ -189,7 +283,7 @@ class MaoboApp(QApplication):
             lastOne=self.statuses[-1]
             if lastOne["if_gap"]==1:
                 self.logger.debug("remove the gap because it is the last one.")
-                self.statuses.remove(lastOne)
+                #self.statuses.remove(lastOne)
             #don't provide loadmore for favorite timeline
             if self.timelineType!=Utils.TIMELINE_TYPE_FAVOUR:
                 self.statuses.append(self.moreOpe)
@@ -197,8 +291,10 @@ class MaoboApp(QApplication):
         if self.timelineType!=Utils.TIMELINE_TYPE_FAVOUR:
             self.statuses.insert(0,self.updateOpe)
         self.timelineWin.load_statuses(self.statuses)
-        self.timelineWin.statusesListView.scrollToTop()
+        self.timelineWin.statusesListView.scrollToTop()        
+        self.timelineWin.setWindowTitle(self.currentAccount["nickname"])
         self.timelineWin.show()
+        self.timelineWin.switch(Utils.g_orietation)
 
     def status_clicked(self,index):
         self.logger.debug("status_clicked")
@@ -246,11 +342,95 @@ class MaoboApp(QApplication):
                 
             else:
                 self.logger.debug("show it")
-                #so just show the status
-                self.currentStatus=status
-                self.show_status_window(status)
+                if self.timelineType !=Utils.TIMELINE_TYPE_COMMENTS: 
+                    #so just show the status
+                    self.currentStatus=status
+                    self.show_status_window(status)
+                else:
+                    self.currentStatus=status
+                    self.create_new_status_window(self.timelineWin)
+                    if self.currentStatus["status"] != None:
+                        self.newStatusWin.iOriginalID = self.currentStatus["status"]["id"]
+                    else:
+                        self.newStatusWin.iOriginalID = self.currentStatus["id"]
+                    #print str(self.currentStatus["status"]["id"]) + ":" + self.currentStatus["status"]["text"]
+                    self.newStatusWin.setWindowTitle(self.currentAccount["nickname"])
+                    self.newStatusWin.load_status(self.currentStatus,Utils.TIMELINE_TYPE_COMMENTS, 1)
+                    self.newStatusWin.show()
+                
+    def cm_List_clicked(self,index):
+        self.logger.debug("cm_List_clicked")
+        row=index.row()
+        #print str(row)
+        if row != 0:
+            self.statusWin.ReplyBtn.setEnabled(True)
+            self.statusWin.reply_status=self.statusWin.comment_statuses[row]
+            #print self.statusWin.reply_status["id"]
+            self.statusWin.iOriginalID = self.statusWin.status["id"]
+            #print self.statusWin.iOriginalID
+            
+
+
+    def cm_status_clicked(self):
+        self.logger.debug("status_clicked")
+        #row=index.row()
+        #status=self.statusWin.statuses[row]
+
+        if self.statusWin.bCommentFlag == 0:
+            try:
+            #type=status["type"]
+            #self.logger.debug("type:"+str(type))
+            # if type==Utils.STATUS_OPE_TYPE_COMMENT:
+               self.update_comments()
+               
+            except KeyError,ae:
+                pass
+        else:
+            self.statusWin.hide_comments()
         
 
+    def update_comments(self):
+        self.logger.debug("update_comments")
+        if self.updater.isRunning():
+            self.logger.debug("updater is running!")
+            self.show_notice("后台运行中，请稍候重试")
+            return
+        self.statusWin.commentsOpe["name"]="updating, please wait"
+        self.statusWin.commentsOpe["lastUpdated"]=None
+        self.statusWin.load_status()
+        self.statusWin.setWindowTitle(self.currentAccount["nickname"])
+        self.statusWin.currentOpe=self.statusWin.commentsOpe
+        
+        if self.currentAccount["website"]==1:
+            sinceId=None
+            if len(self.statuses)>1:
+                latestStatus=self.statuses[1]
+                sinceId=latestStatus["id"]
+                self.logger.debug("sinceId:"+str(sinceId))
+            
+            self.updater.initialize(self.currentAccount["id"],Utils.TIMELINE_TYPE_ST_COMMENTS,self.statusWin.status["id"],None,self.settings["updatenum"],self.settings["downpic"])
+        else:
+            pageflag=0
+            pagetime=0
+            
+            # rem for binkcn 0926
+            #if len(self.statuses)>1:
+            #    latestStatus=self.statuses[1]
+            #    lasetime=int(latestStatus["bmiddle_pic"])
+            
+                #import time
+                #nowtime = int(time.time())
+                #timediff = nowtime - lasetime
+                    #if timediff <= 86400:
+                    #    pageflag=2
+                    #    pagetime=lasetime
+            print self.statusWin.status["id"]
+            print self.statusWin.status["user"]["name"]
+            self.updater.initialize(self.currentAccount["id"],Utils.TIMELINE_TYPE_ST_COMMENTS,pageflag,pagetime,self.settings["updatenum"],self.settings["downpic"],self.statusWin.status["id"])
+        
+        self.show_notice("更新中...")
+        self.set_windows_status(1)
+        self.updater.start()
 
     def update_timeline(self):
         self.logger.debug("update_fridends_timeline")
@@ -261,6 +441,7 @@ class MaoboApp(QApplication):
         self.updateOpe["name"]="updating, please wait"
         self.updateOpe["lastUpdated"]=None
         self.timelineWin.load_statuses(self.statuses)
+        self.timelineWin.setWindowTitle(self.currentAccount["nickname"])
         self.currentOpe=self.updateOpe
         
         if self.currentAccount["website"]==1:
@@ -304,8 +485,35 @@ class MaoboApp(QApplication):
                     return 1
                 
         return 0
+        
+    def update_comments_finished(self,completed):
+        #print "update_comments_finished"
+        self.logger.debug("update_comments_finished")
+        self.set_windows_status(0)
+        newStatuses=self.updater.timeline
+        
+        self.statusWin.commentsOpe["name"]="Comments"
+        self.statusWin.commentsOpe["lastUpdated"]=None
+        
+        if newStatuses!=None and len(newStatuses)>0:
+            #newStatuses.extend(self.statusWin.comment_statuses)
+            for line in newStatuses:
+                self.commentid_seed = self.commentid_seed + 1
+                line["status_id"] = (self.commentid_seed ) % 65535
+            newStatuses.insert(0, self.statusWin.commentsOpe)   
+            self.statusWin.comment_statuses=newStatuses
+
+            self.statusWin.setWindowTitle(self.currentAccount["nickname"])
+            self.statusWin.load_status()
+        else:
+            self.statusWin.load_status()
+ 
+                        
+        self.statusWin.currentOpe=None
+        
     
     def update_finished(self,completed):
+        #print "update_finished"
         self.logger.debug("update_finished")
         self.set_windows_status(0)
         newStatuses=self.updater.timeline
@@ -319,7 +527,7 @@ class MaoboApp(QApplication):
             for newStatus in tmpStatuses:
                 if self.checkExits(newStatus)==1:
                     newStatuses.remove(newStatus)
-        
+
         if self.currentOpe==self.updateOpe:
             #update the lastUpdateTime for the updateOpe and account
             now=datetime.now()
@@ -339,7 +547,7 @@ class MaoboApp(QApplication):
                     
                     gapStatus=Utils.build_a_gap_status(self.currentAccount["id"])
                     gapStatus["id"]=newStatuses[-1]["id"]-1
-                    gapStatus["created_at"]=self.getMinCreatedAt(newStatuses,self.currentAccount["website"])
+                    gapStatus["created_at"]=self.getMinCreatedAt(newStatuses,self.currentAccount["website"])-timedelta(seconds=1)
                     newStatuses.append(gapStatus)
                 
                 self.controller.save_statuses(self.currentAccount["id"],newStatuses,self.timelineType)
@@ -353,6 +561,7 @@ class MaoboApp(QApplication):
 
                 self.statuses.insert(0,self.updateOpe)
                 self.timelineWin.load_statuses(self.statuses)
+                self.timelineWin.setWindowTitle(self.currentAccount["nickname"])
             elif self.currentOpe==self.moreOpe:
                 repeatOne=newStatuses[0]
                 newStatuses.remove(repeatOne)
@@ -362,6 +571,7 @@ class MaoboApp(QApplication):
                     self.statuses.extend(newStatuses)
                     self.statuses.append(self.moreOpe)
                     self.timelineWin.load_statuses(self.statuses)
+                    self.timelineWin.setWindowTitle(self.currentAccount["nickname"])
             elif self.currentOpe==self.gapOpe:
                 repeatOne=newStatuses[0]
                 row=self.gapRow
@@ -372,7 +582,7 @@ class MaoboApp(QApplication):
                     
                     newgapStatus=Utils.build_a_gap_status(self.currentAccount["id"])
                     newgapStatus["id"]=newStatuses[-1]["id"]-1
-                    newgapStatus["created_at"]=self.getMinCreatedAt(newStatuses,self.currentAccount["website"])
+                    newgapStatus["created_at"]=self.getMinCreatedAt(newStatuses,self.currentAccount["website"])-timedelta(seconds=1)
                     newStatuses.append(newgapStatus)
                 self.controller.save_statuses(self.currentAccount["id"],newStatuses,self.timelineType)
 
@@ -384,8 +594,10 @@ class MaoboApp(QApplication):
                     self.statuses.insert(row+i,newOne)
                 
                 self.timelineWin.load_statuses(self.statuses)
-
-                        
+                self.timelineWin.setWindowTitle(self.currentAccount["nickname"])
+        else:
+            self.timelineWin.load_statuses(self.statuses)
+            
         self.currentOpe=None
         
     def getMinCreatedAt(self, newstatuses, website):
@@ -427,6 +639,7 @@ class MaoboApp(QApplication):
             self.moreOpe["name"]="loading, please wait"
             self.currentOpe=self.moreOpe
             self.timelineWin.load_statuses(self.statuses)
+            self.timelineWin.setWindowTitle(self.currentAccount["nickname"])
             
             if self.currentAccount["website"]==1:
                 oldestStatus=self.statuses[-2]
@@ -451,44 +664,73 @@ class MaoboApp(QApplication):
         else:
             #if the last one is a gap,remove it.
             lastOne=moreStatuses[-1]
-            if lastOne["if_gap"]==1:
-                moreStatuses.remove(lastOne)
+            #if lastOne["if_gap"]==1:
+            #    moreStatuses.remove(lastOne)
             moreOpe=self.statuses[-1]
             self.statuses.remove(moreOpe)
             self.statuses.extend(moreStatuses)
             self.statuses.append(moreOpe)
             self.timelineWin.load_statuses(self.statuses)
+            self.timelineWin.setWindowTitle(self.currentAccount["nickname"])
 
 
     def load_more_timeline_favorite(self):
         pass
 
     def show_status_window(self,status):
-        self.statusWin.load_status(status)
+        print "show_status_window"    
+        print status["id"]
+        
+        #if self.statusWin.status == None or self.statusWin.status["id"]!=status["id"]:
+        self.statusWin.status=status
+        self.statusWin.comment_statuses=[]
+            
         self.statusWin.show()
+        self.statusWin.load_status()
+        self.statusWin.setWindowTitle(self.currentAccount["nickname"])
+        #self.statusWin.switch(self.orientation)
+        self.statusWin.show()
+        self.statusWin.repaint()
 
     def create_new_status_window(self,parent):
-        self.newStatusWin=NewStatusWindow(parent)
+        self.newStatusWin=NewStatusWindow(parent, Utils.g_orietation)
         self.connect(self.newStatusWin.sendBtn,
                      SIGNAL("clicked()"),
                      self.send_a_status)
 
 
     def show_new_status_window(self,status=None):
-        self.create_new_status_window(self.menusWin)
-        self.newStatusWin.load_status()
+        self.create_new_status_window(self.timelineWin)
+        self.newStatusWin.setWindowTitle(self.currentAccount["nickname"])
+        self.newStatusWin.load_status(None, None)
+        self.newStatusWin.switch(Utils.g_orietation)
         self.newStatusWin.show()
 
     def rt_a_status(self):
         self.create_new_status_window(self.statusWin)
+        self.newStatusWin.setWindowTitle(self.currentAccount["nickname"])
         self.newStatusWin.load_status(self.currentStatus,Utils.TIMELINE_TYPE_MENTIONS)
         self.newStatusWin.show()
 
     def comment_a_status(self):
         self.create_new_status_window(self.statusWin)
+        self.newStatusWin.setWindowTitle(self.currentAccount["nickname"])
         self.newStatusWin.load_status(self.currentStatus,Utils.TIMELINE_TYPE_COMMENTS)
+        
         self.newStatusWin.show()
+        
+    def Reply_a_status(self):
+        try:
+            type=self.statusWin.reply_status["type"]
+        except:
+            if self.statusWin.reply_status != None:
+                self.create_new_status_window(self.statusWin)
+                self.newStatusWin.iOriginalID = self.statusWin.iOriginalID
+                self.newStatusWin.setWindowTitle(self.currentAccount["nickname"])
+                self.newStatusWin.load_status(self.statusWin.reply_status,Utils.TIMELINE_TYPE_COMMENTS, 1)
+                self.newStatusWin.show()
 
+        
     def dm_a_status(self):
         self.create_new_status_window(self.statusWin)
         self.newStatusWin.load_status(self.currentStatus,Utils.TIMELINE_TYPE_DM)
@@ -537,8 +779,8 @@ class MaoboApp(QApplication):
         self.set_windows_status(0)
         self.newStatusWin.enable_send(True)
         if completed:
-            self.show_notice("微博已成功发送",0)
-#            self.newStatusWin.hide()
+#            self.show_notice("微博已成功发送",0)
+            self.newStatusWin.hide()
 
 
     def create_accounts_mana_form(self,accounts):
@@ -662,14 +904,14 @@ class MaoboApp(QApplication):
     def set_windows_status(self,busy):
         if busy>0:
             self.accountsWin.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, Qt.Checked)
-            self.menusWin.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, Qt.Checked)
+            #self.menusWin.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, Qt.Checked)
             self.timelineWin.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, Qt.Checked)
             self.statusWin.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, Qt.Checked)
             if self.newStatusWin!=None:
                 self.newStatusWin.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, Qt.Checked)
         else:
             self.accountsWin.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, Qt.Unchecked)
-            self.menusWin.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, Qt.Unchecked)
+            #self.menusWin.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, Qt.Unchecked)
             self.timelineWin.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, Qt.Unchecked)
             self.statusWin.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, Qt.Unchecked)
             if self.newStatusWin!=None:
@@ -698,6 +940,9 @@ class MaoboApp(QApplication):
             else:
                 target.addAction(action)
                 
+# Define a callback that gets called for orientation changes
+def handler(orientation, stand, face, x, y, z):
+    print orientation, stand, face, x, y, z
         
 def main():
     dir=Utils.DATA_FILE_PATH
@@ -727,14 +972,16 @@ def main():
     reload(sys)
     sys.setdefaultencoding('utf8')
     QTextCodec.setCodecForCStrings(QTextCodec.codecForName("UTF-8"))
+
     app = MaoboApp(sys.argv)
     app.setOrganizationName("SkyBlue Works")
     app.setOrganizationDomain("michaelwong.cn")
     app.setApplicationName("maebo")
+    
 #    form = MainWindow()
 #    form.show()
     app.exec_()
-
+    
 
 main()
 
